Function summarizes PoDBAY efficacy statistics (mean, median, confidence intervals) based on the set of estimated efficacies and chosen condfidence level. (Set of efficacies is a vector obtained by number of replications specified by repeatCount. These replications are performed for calculation of a confidence interval. For more details, see the supplementary material of the article).
Usage
EfficacyCI(efficacySet, ci = 0.95)
Arguments
efficacySet
numeric vector: estimated PoDBAY efficacies from PoDBAYEfficacy function.
ci
numeric: required confidence level
Value
named list: mean, median, CILow, CIHigh
Details
Confidence intervals are calculated using quantiles of estimated efficacies.