Learn R Programming

PoDBAY (version 1.4.3)

GenerateNondiseased: Generation of upsampled non-diseased subjects titers

Description

Function upsamples (by random sampling with replacement) titers from the immunogenicity subset to the required size.

If the size of the immunogenicity subset matches the required size, nothing happens and the original titers from the immunogenicity subset are returned.

Usage

GenerateNondiseased(blindNondiseasedTiters, nondiseasedCount)

Arguments

blindNondiseasedTiters

numeric vector: vector of non-diseased subjects titer values

nondiseasedCount

numeric: total number of non-diseased subjects, required size of the non-diseased population

Value

nondiseasedTiters: numeric vector of all non-diseased subjects titers

Details

The inputs should come from immunogenicity subset. "nondiseasedCount" represents number of all non-diseased patients in the clinical trial.

Immunogenicity subset populations are obtained from function BlindSampling. Immunogenicity subset represents a sample from the non-diseased population.

In this function, sampling with replacement to the required "nondiseasedCount" of the immunogenecitry subset is performed. The function is used inside PoDParamEstimation function.

Examples

Run this code
# NOT RUN {
## Data preparation
data(nondiseased)

## Example 1
# Creating imunogenicity subset, method = "Full"
NondiseasedImmunogenicitySubset <- 
    ImmunogenicitySubset(diseased, 
                         nondiseased, 
                         method = list(name = "Full", 
                                       value = "NA"))

# Number of all non-diseased subjects in the clinical trial
nondiseasedGenerationCount <- nondiseased$N

# Upsampling of non-diseased titers
GenerateNondiseased(NondiseasedImmunogenicitySubset$titers, nondiseasedGenerationCount)

# }

Run the code above in your browser using DataLab